@@ -10,7 +10,7 @@ sub filter {
   s/\A\n+//o;
   s/^/our \@EXPORT_BASE;\n/;
 
-  # A chain_sub is a method that returns
+  # A chain_sub is a subroutine that returns
   # itself after its function is done.
   s[^chain_sub\s+(\w+\s*\{)(.*?)^\}]
     [sub $1\n $2    ;\$self\n}]msg;
@@ -43,17 +43,7 @@ sub filter {
 
   # This is for invoking methods without specifying FEAR::API objects
   s(&know_myself)
-    (q(
-       my $self = ref ($_[0]) =~ /^FEAR::API/o ? shift : $_;
-       if($ENV{TRANSLATE_FEAR}){
-         my $___this_subname___ = (caller(0))[3];
-#         print $___this_subname___ ,$/;
-         $___this_subname___ =~ s/^.+:://o;
-#         print $___this_subname___ ,$/;
-         $self->__translate($___this_subname___, @_);
-         return;
-       }
-      ))mego;
+    (q(my $self = ref ($_[0]) ? shift : $_))mego;
   
 
   # For debugging
